@@ -61,12 +61,10 @@ impl ArchivedVCardProperty {
             ArchivedVCardProperty::Jsprop => "JSPROP",
             ArchivedVCardProperty::Begin => "BEGIN",
             ArchivedVCardProperty::End => "END",
-            ArchivedVCardProperty::Other(s) => s.as_str(),
+            ArchivedVCardProperty::Other(ref s) => s,
         }
     }
-}
 
-impl ArchivedVCardProperty {
     // Returns the default value type and whether the property is multi-valued.
     pub(crate) fn default_types(&self) -> (ArchivedValueType, ValueSeparator) {
         match self {
@@ -85,7 +83,7 @@ impl ArchivedVCardProperty {
             ),
             ArchivedVCardProperty::N => (
                 ArchivedValueType::Vcard(ArchivedVCardValueType::Text),
-                ValueSeparator::SemicolonAndComma,
+                ValueSeparator::Semicolon,
             ),
             ArchivedVCardProperty::Nickname => (
                 ArchivedValueType::Vcard(ArchivedVCardValueType::Text),
@@ -106,7 +104,7 @@ impl ArchivedVCardProperty {
             ArchivedVCardProperty::Gender => (ArchivedValueType::Sex, ValueSeparator::Semicolon),
             ArchivedVCardProperty::Adr => (
                 ArchivedValueType::Vcard(ArchivedVCardValueType::Text),
-                ValueSeparator::SemicolonAndComma,
+                ValueSeparator::Semicolon,
             ),
             ArchivedVCardProperty::Tel => (
                 ArchivedValueType::Vcard(ArchivedVCardValueType::Text),
@@ -157,7 +155,7 @@ impl ArchivedVCardProperty {
                 ValueSeparator::None,
             ),
             ArchivedVCardProperty::Categories => (
-                ArchivedValueType::Vcard(ArchivedVCardValueType::Text),
+                ArchivedValueType::Vcard(ArchivedVCardValueType::Uri),
                 ValueSeparator::Comma,
             ),
             ArchivedVCardProperty::Note => (
@@ -263,20 +261,20 @@ impl ArchivedVCardProperty {
                 ArchivedValueType::Vcard(ArchivedVCardValueType::Text),
                 ValueSeparator::None,
             ),
+            ArchivedVCardProperty::Other(_) => (
+                ArchivedValueType::Vcard(ArchivedVCardValueType::Text),
+                ValueSeparator::Semicolon,
+            ),
             ArchivedVCardProperty::Begin | ArchivedVCardProperty::End => (
                 ArchivedValueType::Vcard(ArchivedVCardValueType::Text),
                 ValueSeparator::Skip,
             ),
-            ArchivedVCardProperty::Other(_) => (
-                ArchivedValueType::Vcard(ArchivedVCardValueType::Text),
-                ValueSeparator::None,
-            ),
         }
     }
 }
 
-impl IanaString for ArchivedVCardValueType {
-    fn as_str(&self) -> &'static str {
+impl ArchivedVCardValueType {
+    pub fn as_str(&self) -> &str {
         match self {
             ArchivedVCardValueType::Boolean => "BOOLEAN",
             ArchivedVCardValueType::Date => "DATE",
@@ -290,12 +288,19 @@ impl IanaString for ArchivedVCardValueType {
             ArchivedVCardValueType::Timestamp => "TIMESTAMP",
             ArchivedVCardValueType::Uri => "URI",
             ArchivedVCardValueType::UtcOffset => "UTC-OFFSET",
+            ArchivedVCardValueType::Other(ref s) => s,
         }
     }
 }
 
-impl IanaString for ArchivedVCardLevel {
-    fn as_str(&self) -> &'static str {
+impl AsRef<str> for ArchivedVCardValueType {
+    fn as_ref(&self) -> &str {
+        self.as_str()
+    }
+}
+
+impl ArchivedVCardLevel {
+    pub fn as_str(&self) -> &str {
         match self {
             ArchivedVCardLevel::Beginner => "BEGINNER",
             ArchivedVCardLevel::Average => "AVERAGE",
@@ -307,19 +312,32 @@ impl IanaString for ArchivedVCardLevel {
     }
 }
 
-impl IanaString for ArchivedVCardPhonetic {
-    fn as_str(&self) -> &'static str {
+impl AsRef<str> for ArchivedVCardLevel {
+    fn as_ref(&self) -> &str {
+        self.as_str()
+    }
+}
+
+impl ArchivedVCardPhonetic {
+    pub fn as_str(&self) -> &str {
         match self {
             ArchivedVCardPhonetic::Ipa => "IPA",
             ArchivedVCardPhonetic::Jyut => "JYUT",
             ArchivedVCardPhonetic::Piny => "PINY",
             ArchivedVCardPhonetic::Script => "SCRIPT",
+            ArchivedVCardPhonetic::Other(ref s) => s,
         }
     }
 }
 
-impl IanaString for ArchivedVCardType {
-    fn as_str(&self) -> &'static str {
+impl AsRef<str> for ArchivedVCardPhonetic {
+    fn as_ref(&self) -> &str {
+        self.as_str()
+    }
+}
+
+impl ArchivedVCardType {
+    pub fn as_str(&self) -> &str {
         match self {
             ArchivedVCardType::Work => "WORK",
             ArchivedVCardType::Home => "HOME",
@@ -353,12 +371,19 @@ impl IanaString for ArchivedVCardType {
             ArchivedVCardType::Pager => "PAGER",
             ArchivedVCardType::Textphone => "TEXTPHONE",
             ArchivedVCardType::MainNumber => "MAIN-NUMBER",
+            ArchivedVCardType::Other(ref s) => s,
         }
     }
 }
 
-impl IanaString for ArchivedVCardGramGender {
-    fn as_str(&self) -> &'static str {
+impl AsRef<str> for ArchivedVCardType {
+    fn as_ref(&self) -> &str {
+        self.as_str()
+    }
+}
+
+impl ArchivedVCardGramGender {
+    pub fn as_str(&self) -> &str {
         match self {
             ArchivedVCardGramGender::Animate => "ANIMATE",
             ArchivedVCardGramGender::Common => "COMMON",
@@ -370,8 +395,8 @@ impl IanaString for ArchivedVCardGramGender {
     }
 }
 
-impl IanaString for ArchivedVCardSex {
-    fn as_str(&self) -> &'static str {
+impl ArchivedVCardSex {
+    pub fn as_str(&self) -> &str {
         match self {
             ArchivedVCardSex::Male => "M",
             ArchivedVCardSex::Female => "F",
@@ -382,8 +407,8 @@ impl IanaString for ArchivedVCardSex {
     }
 }
 
-impl IanaString for ArchivedVCardKind {
-    fn as_str(&self) -> &'static str {
+impl ArchivedVCardKind {
+    pub fn as_str(&self) -> &str {
         match self {
             ArchivedVCardKind::Individual => "INDIVIDUAL",
             ArchivedVCardKind::Group => "GROUP",
